ngff_zarr._array_split - ngff-zarr
Description: Module Contents: Functions:,,_array_split,*** From NumPy, adapted for Dask Array’s,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr._array_split`

## Module Contents

### Functions

`_array_split` | *** From NumPy, adapted for Dask Array’s

### API

ngff_zarr._array_split._array_split(ary, indices_or_sections, axis=0)

  *** From NumPy, adapted for Dask Array’s

  Split an array into multiple sub-arrays.

  Please refer to the `split` documentation. The only difference between these functions is that `array_split` allows `indices_or_sections` to be an integer that does not equally divide the axis. For an array of length l that should be split into n sections, it returns l % n sub-arrays of size l//n + 1 and the rest of size l//n.

  ## See Also

  split : Split array into multiple sub-arrays of equal size.

  ## Examples

  > > > x = np.arange(8.0) np.array_split(x, 3) [array([0., 1., 2.]), array([3., 4., 5.]), array([6., 7.])]

  > > > x = np.arange(9) np.array_split(x, 4) [array([0, 1, 2]), array([3, 4]), array([5, 6]), array([7, 8])]